starcluster.ssh

Package starcluster :: Module ssh |
[hide private]
[frames] | no frames]

# Module ssh

source code

ssh.py Friendly Python SSH2 interface. From http://commandline.org.uk/code/ License: LGPL modified by justin riley (justin.t.riley@gmail.com)

Classes | [hide private]
| SSHClient Establishes an SSH connection to a remote host using either password or private key authentication.
| Connection Establishes an SSH connection to a remote host using either password or private key authentication.

Functions | [hide private]
main() Little test when called directly. | source code

Variables | [hide private]
| HAS_TERMIOS = `True`
| __package__ = ``'``starcluster``'``